/* This file is part of GEGL
 *
 * GEGL is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * GEGL is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with GEGL; if not, see <http://www.gnu.org/licenses/>.
 *
 * Copyright 2006 Øyvind Kolås
 */

#ifndef __GEGL_MODULE_META_H__
#define __GEGL_MODULE_META_H__

#include <glib-object.h>

#include <gegl/gegl-types.h>

#include <gegl/buffer/gegl-buffer.h>
#include <gegl/module/geglmoduletypes.h>
#include <gegl/module/geglmodule.h>
#include <gegl/operation/gegl-operation.h>

#endif  /* __GEGL_H__ */
